import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a CustomIPPrefixes. */
export declare class CustomIPPrefixes {
    private readonly client;
    /**
     * Create a CustomIPPrefixes.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Deletes the specified custom IP prefix.
     * @param resourceGroupName The name of the resource group.
     * @param customIpPrefixName The name of the CustomIpPrefix.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, customIpPrefixName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Gets the specified custom IP prefix in a specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param customIpPrefixName The name of the custom IP prefix.
     * @param [options] The optional parameters
     * @returns Promise<Models.CustomIPPrefixesGetResponse>
     */
    get(resourceGroupName: string, customIpPrefixName: string, options?: Models.CustomIPPrefixesGetOptionalParams): Promise<Models.CustomIPPrefixesGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param customIpPrefixName The name of the custom IP prefix.
     * @param callback The callback
     */
    get(resourceGroupName: string, customIpPrefixName: string, callback: msRest.ServiceCallback<Models.CustomIpPrefix>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param customIpPrefixName The name of the custom IP prefix.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, customIpPrefixName: string, options: Models.CustomIPPrefixesGetOptionalParams, callback: msRest.ServiceCallback<Models.CustomIpPrefix>): void;
    /**
     * Creates or updates a custom IP prefix.
     * @param resourceGroupName The name of the resource group.
     * @param customIpPrefixName The name of the custom IP prefix.
     * @param parameters Parameters supplied to the create or update custom IP prefix operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.CustomIPPrefixesCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, customIpPrefixName: string, parameters: Models.CustomIpPrefix, options?: msRest.RequestOptionsBase): Promise<Models.CustomIPPrefixesCreateOrUpdateResponse>;
    /**
     * Updates custom IP prefix tags.
     * @param resourceGroupName The name of the resource group.
     * @param customIpPrefixName The name of the custom IP prefix.
     * @param parameters Parameters supplied to update custom IP prefix tags.
     * @param [options] The optional parameters
     * @returns Promise<Models.CustomIPPrefixesUpdateTagsResponse>
     */
    updateTags(resourceGroupName: string, customIpPrefixName: string, parameters: Models.TagsObject, options?: msRest.RequestOptionsBase): Promise<Models.CustomIPPrefixesUpdateTagsResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param customIpPrefixName The name of the custom IP prefix.
     * @param parameters Parameters supplied to update custom IP prefix tags.
     * @param callback The callback
     */
    updateTags(resourceGroupName: string, customIpPrefixName: string, parameters: Models.TagsObject, callback: msRest.ServiceCallback<Models.CustomIpPrefix>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param customIpPrefixName The name of the custom IP prefix.
     * @param parameters Parameters supplied to update custom IP prefix tags.
     * @param options The optional parameters
     * @param callback The callback
     */
    updateTags(resourceGroupName: string, customIpPrefixName: string, parameters: Models.TagsObject, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.CustomIpPrefix>): void;
    /**
     * Gets all the custom IP prefixes in a subscription.
     * @param [options] The optional parameters
     * @returns Promise<Models.CustomIPPrefixesListAllResponse>
     */
    listAll(options?: msRest.RequestOptionsBase): Promise<Models.CustomIPPrefixesListAllResponse>;
    /**
     * @param callback The callback
     */
    listAll(callback: msRest.ServiceCallback<Models.CustomIpPrefixListResult>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    listAll(options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.CustomIpPrefixListResult>): void;
    /**
     * Gets all custom IP prefixes in a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param [options] The optional parameters
     * @returns Promise<Models.CustomIPPrefixesListResponse>
     */
    list(resourceGroupName: string, options?: msRest.RequestOptionsBase): Promise<Models.CustomIPPrefixesListResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param callback The callback
     */
    list(resourceGroupName: string, callback: msRest.ServiceCallback<Models.CustomIpPrefixListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.CustomIpPrefixListResult>): void;
    /**
     * Deletes the specified custom IP prefix.
     * @param resourceGroupName The name of the resource group.
     * @param customIpPrefixName The name of the CustomIpPrefix.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, customIpPrefixName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Creates or updates a custom IP prefix.
     * @param resourceGroupName The name of the resource group.
     * @param customIpPrefixName The name of the custom IP prefix.
     * @param parameters Parameters supplied to the create or update custom IP prefix operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, customIpPrefixName: string, parameters: Models.CustomIpPrefix, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Gets all the custom IP prefixes in a subscription.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.CustomIPPrefixesListAllNextResponse>
     */
    listAllNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.CustomIPPrefixesListAllNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listAllNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.CustomIpPrefixListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listAllNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.CustomIpPrefixListResult>): void;
    /**
     * Gets all custom IP prefixes in a resource group.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.CustomIPPrefixesListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.CustomIPPrefixesListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.CustomIpPrefixListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.CustomIpPrefixListResult>): void;
}
//# sourceMappingURL=customIPPrefixes.d.ts.map