/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/ddosCustomPoliciesMappers";
import * as Parameters from "../models/parameters";
/** Class representing a DdosCustomPolicies. */
var DdosCustomPolicies = /** @class */ (function () {
    /**
     * Create a DdosCustomPolicies.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function DdosCustomPolicies(client) {
        this.client = client;
    }
    /**
     * Deletes the specified DDoS custom policy.
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    DdosCustomPolicies.prototype.deleteMethod = function (resourceGroupName, ddosCustomPolicyName, options) {
        return this.beginDeleteMethod(resourceGroupName, ddosCustomPolicyName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    DdosCustomPolicies.prototype.get = function (resourceGroupName, ddosCustomPolicyName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            ddosCustomPolicyName: ddosCustomPolicyName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a DDoS custom policy.
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param parameters Parameters supplied to the create or update operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DdosCustomPoliciesCreateOrUpdateResponse>
     */
    DdosCustomPolicies.prototype.createOrUpdate = function (resourceGroupName, ddosCustomPolicyName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, ddosCustomPolicyName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    DdosCustomPolicies.prototype.updateTags = function (resourceGroupName, ddosCustomPolicyName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            ddosCustomPolicyName: ddosCustomPolicyName,
            parameters: parameters,
            options: options
        }, updateTagsOperationSpec, callback);
    };
    /**
     * Deletes the specified DDoS custom policy.
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    DdosCustomPolicies.prototype.beginDeleteMethod = function (resourceGroupName, ddosCustomPolicyName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            ddosCustomPolicyName: ddosCustomPolicyName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a DDoS custom policy.
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param parameters Parameters supplied to the create or update operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    DdosCustomPolicies.prototype.beginCreateOrUpdate = function (resourceGroupName, ddosCustomPolicyName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            ddosCustomPolicyName: ddosCustomPolicyName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    return DdosCustomPolicies;
}());
export { DdosCustomPolicies };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/ddosCustomPolicies/{ddosCustomPolicyName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.ddosCustomPolicyName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.DdosCustomPolicy
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var updateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/ddosCustomPolicies/{ddosCustomPolicyName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.ddosCustomPolicyName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.DdosCustomPolicy
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/ddosCustomPolicies/{ddosCustomPolicyName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.ddosCustomPolicyName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/ddosCustomPolicies/{ddosCustomPolicyName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.ddosCustomPolicyName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.DdosCustomPolicy), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.DdosCustomPolicy
        },
        201: {
            bodyMapper: Mappers.DdosCustomPolicy
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=ddosCustomPolicies.js.map