/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/expressRouteCrossConnectionPeeringsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a ExpressRouteCrossConnectionPeerings. */
var ExpressRouteCrossConnectionPeerings = /** @class */ (function () {
    /**
     * Create a ExpressRouteCrossConnectionPeerings.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function ExpressRouteCrossConnectionPeerings(client) {
        this.client = client;
    }
    ExpressRouteCrossConnectionPeerings.prototype.list = function (resourceGroupName, crossConnectionName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            crossConnectionName: crossConnectionName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified peering from the ExpressRouteCrossConnection.
     * @param resourceGroupName The name of the resource group.
     * @param crossConnectionName The name of the ExpressRouteCrossConnection.
     * @param peeringName The name of the peering.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ExpressRouteCrossConnectionPeerings.prototype.deleteMethod = function (resourceGroupName, crossConnectionName, peeringName, options) {
        return this.beginDeleteMethod(resourceGroupName, crossConnectionName, peeringName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteCrossConnectionPeerings.prototype.get = function (resourceGroupName, crossConnectionName, peeringName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            crossConnectionName: crossConnectionName,
            peeringName: peeringName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a peering in the specified ExpressRouteCrossConnection.
     * @param resourceGroupName The name of the resource group.
     * @param crossConnectionName The name of the ExpressRouteCrossConnection.
     * @param peeringName The name of the peering.
     * @param peeringParameters Parameters supplied to the create or update ExpressRouteCrossConnection
     * peering operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteCrossConnectionPeeringsCreateOrUpdateResponse>
     */
    ExpressRouteCrossConnectionPeerings.prototype.createOrUpdate = function (resourceGroupName, crossConnectionName, peeringName, peeringParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, crossConnectionName, peeringName, peeringParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes the specified peering from the ExpressRouteCrossConnection.
     * @param resourceGroupName The name of the resource group.
     * @param crossConnectionName The name of the ExpressRouteCrossConnection.
     * @param peeringName The name of the peering.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCrossConnectionPeerings.prototype.beginDeleteMethod = function (resourceGroupName, crossConnectionName, peeringName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            crossConnectionName: crossConnectionName,
            peeringName: peeringName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a peering in the specified ExpressRouteCrossConnection.
     * @param resourceGroupName The name of the resource group.
     * @param crossConnectionName The name of the ExpressRouteCrossConnection.
     * @param peeringName The name of the peering.
     * @param peeringParameters Parameters supplied to the create or update ExpressRouteCrossConnection
     * peering operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCrossConnectionPeerings.prototype.beginCreateOrUpdate = function (resourceGroupName, crossConnectionName, peeringName, peeringParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            crossConnectionName: crossConnectionName,
            peeringName: peeringName,
            peeringParameters: peeringParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    ExpressRouteCrossConnectionPeerings.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return ExpressRouteCrossConnectionPeerings;
}());
export { ExpressRouteCrossConnectionPeerings };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCrossConnections/{crossConnectionName}/peerings",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.crossConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCrossConnectionPeeringList
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCrossConnections/{crossConnectionName}/peerings/{peeringName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.crossConnectionName,
        Parameters.peeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCrossConnectionPeering
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCrossConnections/{crossConnectionName}/peerings/{peeringName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.crossConnectionName,
        Parameters.peeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCrossConnections/{crossConnectionName}/peerings/{peeringName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.crossConnectionName,
        Parameters.peeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "peeringParameters",
        mapper: __assign(__assign({}, Mappers.ExpressRouteCrossConnectionPeering), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCrossConnectionPeering
        },
        201: {
            bodyMapper: Mappers.ExpressRouteCrossConnectionPeering
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCrossConnectionPeeringList
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=expressRouteCrossConnectionPeerings.js.map