import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a NatRules. */
export declare class NatRules {
    private readonly client;
    /**
     * Create a NatRules.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Retrieves the details of a nat ruleGet.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param [options] The optional parameters
     * @returns Promise<Models.NatRulesGetResponse>
     */
    get(resourceGroupName: string, gatewayName: string, natRuleName: string, options?: msRest.RequestOptionsBase): Promise<Models.NatRulesGetResponse>;
    /**
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param callback The callback
     */
    get(resourceGroupName: string, gatewayName: string, natRuleName: string, callback: msRest.ServiceCallback<Models.VpnGatewayNatRule>): void;
    /**
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, gatewayName: string, natRuleName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.VpnGatewayNatRule>): void;
    /**
     * Creates a nat rule to a scalable vpn gateway if it doesn't exist else updates the existing nat
     * rules.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param natRuleParameters Parameters supplied to create or Update a Nat Rule.
     * @param [options] The optional parameters
     * @returns Promise<Models.NatRulesCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, gatewayName: string, natRuleName: string, natRuleParameters: Models.VpnGatewayNatRule, options?: msRest.RequestOptionsBase): Promise<Models.NatRulesCreateOrUpdateResponse>;
    /**
     * Deletes a nat rule.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, gatewayName: string, natRuleName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Retrieves all nat rules for a particular virtual wan vpn gateway.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.NatRulesListByVpnGatewayResponse>
     */
    listByVpnGateway(resourceGroupName: string, gatewayName: string, options?: msRest.RequestOptionsBase): Promise<Models.NatRulesListByVpnGatewayResponse>;
    /**
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param callback The callback
     */
    listByVpnGateway(resourceGroupName: string, gatewayName: string, callback: msRest.ServiceCallback<Models.ListVpnGatewayNatRulesResult>): void;
    /**
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByVpnGateway(resourceGroupName: string, gatewayName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVpnGatewayNatRulesResult>): void;
    /**
     * Creates a nat rule to a scalable vpn gateway if it doesn't exist else updates the existing nat
     * rules.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param natRuleParameters Parameters supplied to create or Update a Nat Rule.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, gatewayName: string, natRuleName: string, natRuleParameters: Models.VpnGatewayNatRule, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Deletes a nat rule.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, gatewayName: string, natRuleName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Retrieves all nat rules for a particular virtual wan vpn gateway.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.NatRulesListByVpnGatewayNextResponse>
     */
    listByVpnGatewayNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.NatRulesListByVpnGatewayNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByVpnGatewayNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ListVpnGatewayNatRulesResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByVpnGatewayNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVpnGatewayNatRulesResult>): void;
}
//# sourceMappingURL=natRules.d.ts.map