/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/natRulesMappers";
import * as Parameters from "../models/parameters";
/** Class representing a NatRules. */
var NatRules = /** @class */ (function () {
    /**
     * Create a NatRules.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function NatRules(client) {
        this.client = client;
    }
    NatRules.prototype.get = function (resourceGroupName, gatewayName, natRuleName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            natRuleName: natRuleName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates a nat rule to a scalable vpn gateway if it doesn't exist else updates the existing nat
     * rules.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param natRuleParameters Parameters supplied to create or Update a Nat Rule.
     * @param [options] The optional parameters
     * @returns Promise<Models.NatRulesCreateOrUpdateResponse>
     */
    NatRules.prototype.createOrUpdate = function (resourceGroupName, gatewayName, natRuleName, natRuleParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, gatewayName, natRuleName, natRuleParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes a nat rule.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    NatRules.prototype.deleteMethod = function (resourceGroupName, gatewayName, natRuleName, options) {
        return this.beginDeleteMethod(resourceGroupName, gatewayName, natRuleName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    NatRules.prototype.listByVpnGateway = function (resourceGroupName, gatewayName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            options: options
        }, listByVpnGatewayOperationSpec, callback);
    };
    /**
     * Creates a nat rule to a scalable vpn gateway if it doesn't exist else updates the existing nat
     * rules.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param natRuleParameters Parameters supplied to create or Update a Nat Rule.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NatRules.prototype.beginCreateOrUpdate = function (resourceGroupName, gatewayName, natRuleName, natRuleParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            natRuleName: natRuleName,
            natRuleParameters: natRuleParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes a nat rule.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NatRules.prototype.beginDeleteMethod = function (resourceGroupName, gatewayName, natRuleName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            natRuleName: natRuleName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    NatRules.prototype.listByVpnGatewayNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listByVpnGatewayNextOperationSpec, callback);
    };
    return NatRules;
}());
export { NatRules };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnGateways/{gatewayName}/natRules/{natRuleName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.natRuleName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VpnGatewayNatRule
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByVpnGatewayOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnGateways/{gatewayName}/natRules",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListVpnGatewayNatRulesResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnGateways/{gatewayName}/natRules/{natRuleName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.natRuleName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "natRuleParameters",
        mapper: __assign(__assign({}, Mappers.VpnGatewayNatRule), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VpnGatewayNatRule
        },
        201: {
            bodyMapper: Mappers.VpnGatewayNatRule
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnGateways/{gatewayName}/natRules/{natRuleName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.natRuleName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByVpnGatewayNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListVpnGatewayNatRulesResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=natRules.js.map