/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/networkInterfaceTapConfigurationsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a NetworkInterfaceTapConfigurations. */
var NetworkInterfaceTapConfigurations = /** @class */ (function () {
    /**
     * Create a NetworkInterfaceTapConfigurations.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function NetworkInterfaceTapConfigurations(client) {
        this.client = client;
    }
    /**
     * Deletes the specified tap configuration from the NetworkInterface.
     * @param resourceGroupName The name of the resource group.
     * @param networkInterfaceName The name of the network interface.
     * @param tapConfigurationName The name of the tap configuration.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    NetworkInterfaceTapConfigurations.prototype.deleteMethod = function (resourceGroupName, networkInterfaceName, tapConfigurationName, options) {
        return this.beginDeleteMethod(resourceGroupName, networkInterfaceName, tapConfigurationName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    NetworkInterfaceTapConfigurations.prototype.get = function (resourceGroupName, networkInterfaceName, tapConfigurationName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkInterfaceName: networkInterfaceName,
            tapConfigurationName: tapConfigurationName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a Tap configuration in the specified NetworkInterface.
     * @param resourceGroupName The name of the resource group.
     * @param networkInterfaceName The name of the network interface.
     * @param tapConfigurationName The name of the tap configuration.
     * @param tapConfigurationParameters Parameters supplied to the create or update tap configuration
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.NetworkInterfaceTapConfigurationsCreateOrUpdateResponse>
     */
    NetworkInterfaceTapConfigurations.prototype.createOrUpdate = function (resourceGroupName, networkInterfaceName, tapConfigurationName, tapConfigurationParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, networkInterfaceName, tapConfigurationName, tapConfigurationParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    NetworkInterfaceTapConfigurations.prototype.list = function (resourceGroupName, networkInterfaceName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkInterfaceName: networkInterfaceName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified tap configuration from the NetworkInterface.
     * @param resourceGroupName The name of the resource group.
     * @param networkInterfaceName The name of the network interface.
     * @param tapConfigurationName The name of the tap configuration.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkInterfaceTapConfigurations.prototype.beginDeleteMethod = function (resourceGroupName, networkInterfaceName, tapConfigurationName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkInterfaceName: networkInterfaceName,
            tapConfigurationName: tapConfigurationName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a Tap configuration in the specified NetworkInterface.
     * @param resourceGroupName The name of the resource group.
     * @param networkInterfaceName The name of the network interface.
     * @param tapConfigurationName The name of the tap configuration.
     * @param tapConfigurationParameters Parameters supplied to the create or update tap configuration
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkInterfaceTapConfigurations.prototype.beginCreateOrUpdate = function (resourceGroupName, networkInterfaceName, tapConfigurationName, tapConfigurationParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkInterfaceName: networkInterfaceName,
            tapConfigurationName: tapConfigurationName,
            tapConfigurationParameters: tapConfigurationParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    NetworkInterfaceTapConfigurations.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return NetworkInterfaceTapConfigurations;
}());
export { NetworkInterfaceTapConfigurations };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkInterfaces/{networkInterfaceName}/tapConfigurations/{tapConfigurationName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkInterfaceName,
        Parameters.tapConfigurationName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.NetworkInterfaceTapConfiguration
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkInterfaces/{networkInterfaceName}/tapConfigurations",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkInterfaceName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.NetworkInterfaceTapConfigurationListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkInterfaces/{networkInterfaceName}/tapConfigurations/{tapConfigurationName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkInterfaceName,
        Parameters.tapConfigurationName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkInterfaces/{networkInterfaceName}/tapConfigurations/{tapConfigurationName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkInterfaceName,
        Parameters.tapConfigurationName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "tapConfigurationParameters",
        mapper: __assign(__assign({}, Mappers.NetworkInterfaceTapConfiguration), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.NetworkInterfaceTapConfiguration
        },
        201: {
            bodyMapper: Mappers.NetworkInterfaceTapConfiguration
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.NetworkInterfaceTapConfigurationListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=networkInterfaceTapConfigurations.js.map