/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/p2sVpnGatewaysMappers";
import * as Parameters from "../models/parameters";
/** Class representing a P2sVpnGateways. */
var P2sVpnGateways = /** @class */ (function () {
    /**
     * Create a P2sVpnGateways.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function P2sVpnGateways(client) {
        this.client = client;
    }
    P2sVpnGateways.prototype.get = function (resourceGroupName, gatewayName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates a virtual wan p2s vpn gateway if it doesn't exist else updates the existing gateway.
     * @param resourceGroupName The resource group name of the P2SVpnGateway.
     * @param gatewayName The name of the gateway.
     * @param p2SVpnGatewayParameters Parameters supplied to create or Update a virtual wan p2s vpn
     * gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.P2sVpnGatewaysCreateOrUpdateResponse>
     */
    P2sVpnGateways.prototype.createOrUpdate = function (resourceGroupName, gatewayName, p2SVpnGatewayParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, gatewayName, p2SVpnGatewayParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Updates virtual wan p2s vpn gateway tags.
     * @param resourceGroupName The resource group name of the P2SVpnGateway.
     * @param gatewayName The name of the gateway.
     * @param p2SVpnGatewayParameters Parameters supplied to update a virtual wan p2s vpn gateway tags.
     * @param [options] The optional parameters
     * @returns Promise<Models.P2sVpnGatewaysUpdateTagsResponse>
     */
    P2sVpnGateways.prototype.updateTags = function (resourceGroupName, gatewayName, p2SVpnGatewayParameters, options) {
        return this.beginUpdateTags(resourceGroupName, gatewayName, p2SVpnGatewayParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes a virtual wan p2s vpn gateway.
     * @param resourceGroupName The resource group name of the P2SVpnGateway.
     * @param gatewayName The name of the gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    P2sVpnGateways.prototype.deleteMethod = function (resourceGroupName, gatewayName, options) {
        return this.beginDeleteMethod(resourceGroupName, gatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    P2sVpnGateways.prototype.listByResourceGroup = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listByResourceGroupOperationSpec, callback);
    };
    P2sVpnGateways.prototype.list = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Resets the primary of the p2s vpn gateway in the specified resource group.
     * @param resourceGroupName The resource group name of the P2SVpnGateway.
     * @param gatewayName The name of the gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.P2sVpnGatewaysResetResponse>
     */
    P2sVpnGateways.prototype.reset = function (resourceGroupName, gatewayName, options) {
        return this.beginReset(resourceGroupName, gatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Generates VPN profile for P2S client of the P2SVpnGateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the P2SVpnGateway.
     * @param parameters Parameters supplied to the generate P2SVpnGateway VPN client package
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.P2sVpnGatewaysGenerateVpnProfileResponse>
     */
    P2sVpnGateways.prototype.generateVpnProfile = function (resourceGroupName, gatewayName, parameters, options) {
        return this.beginGenerateVpnProfile(resourceGroupName, gatewayName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Gets the connection health of P2S clients of the virtual wan P2SVpnGateway in the specified
     * resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the P2SVpnGateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.P2sVpnGatewaysGetP2sVpnConnectionHealthResponse>
     */
    P2sVpnGateways.prototype.getP2sVpnConnectionHealth = function (resourceGroupName, gatewayName, options) {
        return this.beginGetP2sVpnConnectionHealth(resourceGroupName, gatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Gets the sas url to get the connection health detail of P2S clients of the virtual wan
     * P2SVpnGateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the P2SVpnGateway.
     * @param request Request parameters supplied to get p2s vpn connections detailed health.
     * @param [options] The optional parameters
     * @returns Promise<Models.P2sVpnGatewaysGetP2sVpnConnectionHealthDetailedResponse>
     */
    P2sVpnGateways.prototype.getP2sVpnConnectionHealthDetailed = function (resourceGroupName, gatewayName, request, options) {
        return this.beginGetP2sVpnConnectionHealthDetailed(resourceGroupName, gatewayName, request, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Disconnect P2S vpn connections of the virtual wan P2SVpnGateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param p2sVpnGatewayName The name of the P2S Vpn Gateway.
     * @param request The parameters are supplied to disconnect p2s vpn connections.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    P2sVpnGateways.prototype.disconnectP2sVpnConnections = function (resourceGroupName, p2sVpnGatewayName, request, options) {
        return this.beginDisconnectP2sVpnConnections(resourceGroupName, p2sVpnGatewayName, request, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Creates a virtual wan p2s vpn gateway if it doesn't exist else updates the existing gateway.
     * @param resourceGroupName The resource group name of the P2SVpnGateway.
     * @param gatewayName The name of the gateway.
     * @param p2SVpnGatewayParameters Parameters supplied to create or Update a virtual wan p2s vpn
     * gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    P2sVpnGateways.prototype.beginCreateOrUpdate = function (resourceGroupName, gatewayName, p2SVpnGatewayParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            p2SVpnGatewayParameters: p2SVpnGatewayParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Updates virtual wan p2s vpn gateway tags.
     * @param resourceGroupName The resource group name of the P2SVpnGateway.
     * @param gatewayName The name of the gateway.
     * @param p2SVpnGatewayParameters Parameters supplied to update a virtual wan p2s vpn gateway tags.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    P2sVpnGateways.prototype.beginUpdateTags = function (resourceGroupName, gatewayName, p2SVpnGatewayParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            p2SVpnGatewayParameters: p2SVpnGatewayParameters,
            options: options
        }, beginUpdateTagsOperationSpec, options);
    };
    /**
     * Deletes a virtual wan p2s vpn gateway.
     * @param resourceGroupName The resource group name of the P2SVpnGateway.
     * @param gatewayName The name of the gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    P2sVpnGateways.prototype.beginDeleteMethod = function (resourceGroupName, gatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Resets the primary of the p2s vpn gateway in the specified resource group.
     * @param resourceGroupName The resource group name of the P2SVpnGateway.
     * @param gatewayName The name of the gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    P2sVpnGateways.prototype.beginReset = function (resourceGroupName, gatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            options: options
        }, beginResetOperationSpec, options);
    };
    /**
     * Generates VPN profile for P2S client of the P2SVpnGateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the P2SVpnGateway.
     * @param parameters Parameters supplied to the generate P2SVpnGateway VPN client package
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    P2sVpnGateways.prototype.beginGenerateVpnProfile = function (resourceGroupName, gatewayName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            parameters: parameters,
            options: options
        }, beginGenerateVpnProfileOperationSpec, options);
    };
    /**
     * Gets the connection health of P2S clients of the virtual wan P2SVpnGateway in the specified
     * resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the P2SVpnGateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    P2sVpnGateways.prototype.beginGetP2sVpnConnectionHealth = function (resourceGroupName, gatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            options: options
        }, beginGetP2sVpnConnectionHealthOperationSpec, options);
    };
    /**
     * Gets the sas url to get the connection health detail of P2S clients of the virtual wan
     * P2SVpnGateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the P2SVpnGateway.
     * @param request Request parameters supplied to get p2s vpn connections detailed health.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    P2sVpnGateways.prototype.beginGetP2sVpnConnectionHealthDetailed = function (resourceGroupName, gatewayName, request, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            request: request,
            options: options
        }, beginGetP2sVpnConnectionHealthDetailedOperationSpec, options);
    };
    /**
     * Disconnect P2S vpn connections of the virtual wan P2SVpnGateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param p2sVpnGatewayName The name of the P2S Vpn Gateway.
     * @param request The parameters are supplied to disconnect p2s vpn connections.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    P2sVpnGateways.prototype.beginDisconnectP2sVpnConnections = function (resourceGroupName, p2sVpnGatewayName, request, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            p2sVpnGatewayName: p2sVpnGatewayName,
            request: request,
            options: options
        }, beginDisconnectP2sVpnConnectionsOperationSpec, options);
    };
    P2sVpnGateways.prototype.listByResourceGroupNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listByResourceGroupNextOperationSpec, callback);
    };
    P2sVpnGateways.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return P2sVpnGateways;
}());
export { P2sVpnGateways };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/p2svpnGateways/{gatewayName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.P2SVpnGateway
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByResourceGroupOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/p2svpnGateways",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListP2SVpnGatewaysResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/p2svpnGateways",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListP2SVpnGatewaysResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/p2svpnGateways/{gatewayName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "p2SVpnGatewayParameters",
        mapper: __assign(__assign({}, Mappers.P2SVpnGateway), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.P2SVpnGateway
        },
        201: {
            bodyMapper: Mappers.P2SVpnGateway
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginUpdateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/p2svpnGateways/{gatewayName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "p2SVpnGatewayParameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.P2SVpnGateway
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/p2svpnGateways/{gatewayName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginResetOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/p2svpnGateways/{gatewayName}/reset",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.P2SVpnGateway
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginGenerateVpnProfileOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/p2svpnGateways/{gatewayName}/generatevpnprofile",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.P2SVpnProfileParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VpnProfileResponse
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginGetP2sVpnConnectionHealthOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/p2svpnGateways/{gatewayName}/getP2sVpnConnectionHealth",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.P2SVpnGateway
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginGetP2sVpnConnectionHealthDetailedOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/p2svpnGateways/{gatewayName}/getP2sVpnConnectionHealthDetailed",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "request",
        mapper: __assign(__assign({}, Mappers.P2SVpnConnectionHealthRequest), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.P2SVpnConnectionHealth
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDisconnectP2sVpnConnectionsOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/p2svpnGateways/{p2sVpnGatewayName}/disconnectP2sVpnConnections",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.p2sVpnGatewayName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "request",
        mapper: __assign(__assign({}, Mappers.P2SVpnConnectionRequest), { required: true })
    },
    responses: {
        200: {},
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByResourceGroupNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListP2SVpnGatewaysResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListP2SVpnGatewaysResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=p2sVpnGateways.js.map