import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a PeerExpressRouteCircuitConnections. */
export declare class PeerExpressRouteCircuitConnections {
    private readonly client;
    /**
     * Create a PeerExpressRouteCircuitConnections.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Gets the specified Peer Express Route Circuit Connection from the specified express route
     * circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param connectionName The name of the peer express route circuit connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.PeerExpressRouteCircuitConnectionsGetResponse>
     */
    get(resourceGroupName: string, circuitName: string, peeringName: string, connectionName: string, options?: msRest.RequestOptionsBase): Promise<Models.PeerExpressRouteCircuitConnectionsGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param connectionName The name of the peer express route circuit connection.
     * @param callback The callback
     */
    get(resourceGroupName: string, circuitName: string, peeringName: string, connectionName: string, callback: msRest.ServiceCallback<Models.PeerExpressRouteCircuitConnection>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param connectionName The name of the peer express route circuit connection.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, circuitName: string, peeringName: string, connectionName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PeerExpressRouteCircuitConnection>): void;
    /**
     * Gets all global reach peer connections associated with a private peering in an express route
     * circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the circuit.
     * @param peeringName The name of the peering.
     * @param [options] The optional parameters
     * @returns Promise<Models.PeerExpressRouteCircuitConnectionsListResponse>
     */
    list(resourceGroupName: string, circuitName: string, peeringName: string, options?: msRest.RequestOptionsBase): Promise<Models.PeerExpressRouteCircuitConnectionsListResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the circuit.
     * @param peeringName The name of the peering.
     * @param callback The callback
     */
    list(resourceGroupName: string, circuitName: string, peeringName: string, callback: msRest.ServiceCallback<Models.PeerExpressRouteCircuitConnectionListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the circuit.
     * @param peeringName The name of the peering.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, circuitName: string, peeringName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PeerExpressRouteCircuitConnectionListResult>): void;
    /**
     * Gets all global reach peer connections associated with a private peering in an express route
     * circuit.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PeerExpressRouteCircuitConnectionsListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.PeerExpressRouteCircuitConnectionsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.PeerExpressRouteCircuitConnectionListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PeerExpressRouteCircuitConnectionListResult>): void;
}
//# sourceMappingURL=peerExpressRouteCircuitConnections.d.ts.map