/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/privateDnsZoneGroupsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a PrivateDnsZoneGroups. */
var PrivateDnsZoneGroups = /** @class */ (function () {
    /**
     * Create a PrivateDnsZoneGroups.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function PrivateDnsZoneGroups(client) {
        this.client = client;
    }
    /**
     * Deletes the specified private dns zone group.
     * @param resourceGroupName The name of the resource group.
     * @param privateEndpointName The name of the private endpoint.
     * @param privateDnsZoneGroupName The name of the private dns zone group.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    PrivateDnsZoneGroups.prototype.deleteMethod = function (resourceGroupName, privateEndpointName, privateDnsZoneGroupName, options) {
        return this.beginDeleteMethod(resourceGroupName, privateEndpointName, privateDnsZoneGroupName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    PrivateDnsZoneGroups.prototype.get = function (resourceGroupName, privateEndpointName, privateDnsZoneGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            privateEndpointName: privateEndpointName,
            privateDnsZoneGroupName: privateDnsZoneGroupName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a private dns zone group in the specified private endpoint.
     * @param resourceGroupName The name of the resource group.
     * @param privateEndpointName The name of the private endpoint.
     * @param privateDnsZoneGroupName The name of the private dns zone group.
     * @param parameters Parameters supplied to the create or update private dns zone group operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateDnsZoneGroupsCreateOrUpdateResponse>
     */
    PrivateDnsZoneGroups.prototype.createOrUpdate = function (resourceGroupName, privateEndpointName, privateDnsZoneGroupName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, privateEndpointName, privateDnsZoneGroupName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    PrivateDnsZoneGroups.prototype.list = function (privateEndpointName, resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            privateEndpointName: privateEndpointName,
            resourceGroupName: resourceGroupName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified private dns zone group.
     * @param resourceGroupName The name of the resource group.
     * @param privateEndpointName The name of the private endpoint.
     * @param privateDnsZoneGroupName The name of the private dns zone group.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    PrivateDnsZoneGroups.prototype.beginDeleteMethod = function (resourceGroupName, privateEndpointName, privateDnsZoneGroupName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            privateEndpointName: privateEndpointName,
            privateDnsZoneGroupName: privateDnsZoneGroupName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a private dns zone group in the specified private endpoint.
     * @param resourceGroupName The name of the resource group.
     * @param privateEndpointName The name of the private endpoint.
     * @param privateDnsZoneGroupName The name of the private dns zone group.
     * @param parameters Parameters supplied to the create or update private dns zone group operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    PrivateDnsZoneGroups.prototype.beginCreateOrUpdate = function (resourceGroupName, privateEndpointName, privateDnsZoneGroupName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            privateEndpointName: privateEndpointName,
            privateDnsZoneGroupName: privateDnsZoneGroupName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    PrivateDnsZoneGroups.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return PrivateDnsZoneGroups;
}());
export { PrivateDnsZoneGroups };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateEndpoints/{privateEndpointName}/privateDnsZoneGroups/{privateDnsZoneGroupName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateEndpointName,
        Parameters.privateDnsZoneGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PrivateDnsZoneGroup
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateEndpoints/{privateEndpointName}/privateDnsZoneGroups",
    urlParameters: [
        Parameters.privateEndpointName,
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PrivateDnsZoneGroupListResult
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateEndpoints/{privateEndpointName}/privateDnsZoneGroups/{privateDnsZoneGroupName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateEndpointName,
        Parameters.privateDnsZoneGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateEndpoints/{privateEndpointName}/privateDnsZoneGroups/{privateDnsZoneGroupName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateEndpointName,
        Parameters.privateDnsZoneGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.PrivateDnsZoneGroup), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.PrivateDnsZoneGroup
        },
        201: {
            bodyMapper: Mappers.PrivateDnsZoneGroup
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PrivateDnsZoneGroupListResult
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
//# sourceMappingURL=privateDnsZoneGroups.js.map