/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/virtualApplianceSitesMappers";
import * as Parameters from "../models/parameters";
/** Class representing a VirtualApplianceSites. */
var VirtualApplianceSites = /** @class */ (function () {
    /**
     * Create a VirtualApplianceSites.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function VirtualApplianceSites(client) {
        this.client = client;
    }
    /**
     * Deletes the specified site from a Virtual Appliance.
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param siteName The name of the site.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VirtualApplianceSites.prototype.deleteMethod = function (resourceGroupName, networkVirtualApplianceName, siteName, options) {
        return this.beginDeleteMethod(resourceGroupName, networkVirtualApplianceName, siteName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualApplianceSites.prototype.get = function (resourceGroupName, networkVirtualApplianceName, siteName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkVirtualApplianceName: networkVirtualApplianceName,
            siteName: siteName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates the specified Network Virtual Appliance Site.
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param siteName The name of the site.
     * @param parameters Parameters supplied to the create or update Network Virtual Appliance Site
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualApplianceSitesCreateOrUpdateResponse>
     */
    VirtualApplianceSites.prototype.createOrUpdate = function (resourceGroupName, networkVirtualApplianceName, siteName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, networkVirtualApplianceName, siteName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualApplianceSites.prototype.list = function (resourceGroupName, networkVirtualApplianceName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkVirtualApplianceName: networkVirtualApplianceName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified site from a Virtual Appliance.
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param siteName The name of the site.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualApplianceSites.prototype.beginDeleteMethod = function (resourceGroupName, networkVirtualApplianceName, siteName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkVirtualApplianceName: networkVirtualApplianceName,
            siteName: siteName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates the specified Network Virtual Appliance Site.
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param siteName The name of the site.
     * @param parameters Parameters supplied to the create or update Network Virtual Appliance Site
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualApplianceSites.prototype.beginCreateOrUpdate = function (resourceGroupName, networkVirtualApplianceName, siteName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkVirtualApplianceName: networkVirtualApplianceName,
            siteName: siteName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    VirtualApplianceSites.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return VirtualApplianceSites;
}());
export { VirtualApplianceSites };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkVirtualAppliances/{networkVirtualApplianceName}/virtualApplianceSites/{siteName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkVirtualApplianceName,
        Parameters.siteName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualApplianceSite
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkVirtualAppliances/{networkVirtualApplianceName}/virtualApplianceSites",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkVirtualApplianceName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.NetworkVirtualApplianceSiteListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkVirtualAppliances/{networkVirtualApplianceName}/virtualApplianceSites/{siteName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkVirtualApplianceName,
        Parameters.siteName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkVirtualAppliances/{networkVirtualApplianceName}/virtualApplianceSites/{siteName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkVirtualApplianceName,
        Parameters.siteName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.VirtualApplianceSite), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VirtualApplianceSite
        },
        201: {
            bodyMapper: Mappers.VirtualApplianceSite
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.NetworkVirtualApplianceSiteListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=virtualApplianceSites.js.map