import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a VirtualApplianceSkus. */
export declare class VirtualApplianceSkus {
    private readonly client;
    /**
     * Create a VirtualApplianceSkus.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * List all SKUs available for a virtual appliance.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualApplianceSkusListResponse>
     */
    list(options?: msRest.RequestOptionsBase): Promise<Models.VirtualApplianceSkusListResponse>;
    /**
     * @param callback The callback
     */
    list(callback: msRest.ServiceCallback<Models.NetworkVirtualApplianceSkuListResult>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    list(options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.NetworkVirtualApplianceSkuListResult>): void;
    /**
     * Retrieves a single available sku for network virtual appliance.
     * @param skuName Name of the Sku.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualApplianceSkusGetResponse>
     */
    get(skuName: string, options?: msRest.RequestOptionsBase): Promise<Models.VirtualApplianceSkusGetResponse>;
    /**
     * @param skuName Name of the Sku.
     * @param callback The callback
     */
    get(skuName: string, callback: msRest.ServiceCallback<Models.NetworkVirtualApplianceSku>): void;
    /**
     * @param skuName Name of the Sku.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(skuName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.NetworkVirtualApplianceSku>): void;
    /**
     * List all SKUs available for a virtual appliance.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualApplianceSkusListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.VirtualApplianceSkusListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.NetworkVirtualApplianceSkuListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.NetworkVirtualApplianceSkuListResult>): void;
}
//# sourceMappingURL=virtualApplianceSkus.d.ts.map