/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/virtualHubBgpConnectionMappers";
import * as Parameters from "../models/parameters";
/** Class representing a VirtualHubBgpConnection. */
var VirtualHubBgpConnection = /** @class */ (function () {
    /**
     * Create a VirtualHubBgpConnection.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function VirtualHubBgpConnection(client) {
        this.client = client;
    }
    VirtualHubBgpConnection.prototype.get = function (resourceGroupName, virtualHubName, connectionName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            connectionName: connectionName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates a VirtualHubBgpConnection resource if it doesn't exist else updates the existing
     * VirtualHubBgpConnection.
     * @param resourceGroupName The resource group name of the VirtualHub.
     * @param virtualHubName The name of the VirtualHub.
     * @param connectionName The name of the connection.
     * @param parameters Parameters of Bgp connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualHubBgpConnectionCreateOrUpdateResponse>
     */
    VirtualHubBgpConnection.prototype.createOrUpdate = function (resourceGroupName, virtualHubName, connectionName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, virtualHubName, connectionName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes a VirtualHubBgpConnection.
     * @param resourceGroupName The resource group name of the VirtualHubBgpConnection.
     * @param virtualHubName The name of the VirtualHub.
     * @param connectionName The name of the connection.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VirtualHubBgpConnection.prototype.deleteMethod = function (resourceGroupName, virtualHubName, connectionName, options) {
        return this.beginDeleteMethod(resourceGroupName, virtualHubName, connectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Creates a VirtualHubBgpConnection resource if it doesn't exist else updates the existing
     * VirtualHubBgpConnection.
     * @param resourceGroupName The resource group name of the VirtualHub.
     * @param virtualHubName The name of the VirtualHub.
     * @param connectionName The name of the connection.
     * @param parameters Parameters of Bgp connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualHubBgpConnection.prototype.beginCreateOrUpdate = function (resourceGroupName, virtualHubName, connectionName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            connectionName: connectionName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes a VirtualHubBgpConnection.
     * @param resourceGroupName The resource group name of the VirtualHubBgpConnection.
     * @param virtualHubName The name of the VirtualHub.
     * @param connectionName The name of the connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualHubBgpConnection.prototype.beginDeleteMethod = function (resourceGroupName, virtualHubName, connectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            connectionName: connectionName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    return VirtualHubBgpConnection;
}());
export { VirtualHubBgpConnection };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/bgpConnections/{connectionName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName,
        Parameters.connectionName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.BgpConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/bgpConnections/{connectionName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName,
        Parameters.connectionName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.BgpConnection), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.BgpConnection
        },
        201: {
            bodyMapper: Mappers.BgpConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/bgpConnections/{connectionName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName,
        Parameters.connectionName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=virtualHubBgpConnection.js.map