/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/virtualHubBgpConnectionsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a VirtualHubBgpConnections. */
var VirtualHubBgpConnections = /** @class */ (function () {
    /**
     * Create a VirtualHubBgpConnections.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function VirtualHubBgpConnections(client) {
        this.client = client;
    }
    VirtualHubBgpConnections.prototype.list = function (resourceGroupName, virtualHubName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Retrieves a list of routes the virtual hub bgp connection has learned.
     * @param resourceGroupName The name of the resource group.
     * @param hubName The name of the virtual hub.
     * @param connectionName The name of the virtual hub bgp connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualHubBgpConnectionsListLearnedRoutesResponse>
     */
    VirtualHubBgpConnections.prototype.listLearnedRoutes = function (resourceGroupName, hubName, connectionName, options) {
        return this.beginListLearnedRoutes(resourceGroupName, hubName, connectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Retrieves a list of routes the virtual hub bgp connection is advertising to the specified peer.
     * @param resourceGroupName The name of the resource group.
     * @param hubName The name of the virtual hub.
     * @param connectionName The name of the virtual hub bgp connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualHubBgpConnectionsListAdvertisedRoutesResponse>
     */
    VirtualHubBgpConnections.prototype.listAdvertisedRoutes = function (resourceGroupName, hubName, connectionName, options) {
        return this.beginListAdvertisedRoutes(resourceGroupName, hubName, connectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Retrieves a list of routes the virtual hub bgp connection has learned.
     * @param resourceGroupName The name of the resource group.
     * @param hubName The name of the virtual hub.
     * @param connectionName The name of the virtual hub bgp connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualHubBgpConnections.prototype.beginListLearnedRoutes = function (resourceGroupName, hubName, connectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            hubName: hubName,
            connectionName: connectionName,
            options: options
        }, beginListLearnedRoutesOperationSpec, options);
    };
    /**
     * Retrieves a list of routes the virtual hub bgp connection is advertising to the specified peer.
     * @param resourceGroupName The name of the resource group.
     * @param hubName The name of the virtual hub.
     * @param connectionName The name of the virtual hub bgp connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualHubBgpConnections.prototype.beginListAdvertisedRoutes = function (resourceGroupName, hubName, connectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            hubName: hubName,
            connectionName: connectionName,
            options: options
        }, beginListAdvertisedRoutesOperationSpec, options);
    };
    VirtualHubBgpConnections.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return VirtualHubBgpConnections;
}());
export { VirtualHubBgpConnections };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/bgpConnections",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListVirtualHubBgpConnectionResults
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginListLearnedRoutesOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{hubName}/bgpConnections/{connectionName}/learnedRoutes",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.hubName,
        Parameters.connectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PeerRouteList
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginListAdvertisedRoutesOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{hubName}/bgpConnections/{connectionName}/advertisedRoutes",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.hubName,
        Parameters.connectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PeerRouteList
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListVirtualHubBgpConnectionResults
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=virtualHubBgpConnections.js.map