import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a VirtualNetworkGatewayNatRules. */
export declare class VirtualNetworkGatewayNatRules {
    private readonly client;
    /**
     * Create a VirtualNetworkGatewayNatRules.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Retrieves the details of a nat rule.
     * @param resourceGroupName The resource group name of the Virtual Network Gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewayNatRulesGetResponse>
     */
    get(resourceGroupName: string, virtualNetworkGatewayName: string, natRuleName: string, options?: msRest.RequestOptionsBase): Promise<Models.VirtualNetworkGatewayNatRulesGetResponse>;
    /**
     * @param resourceGroupName The resource group name of the Virtual Network Gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param callback The callback
     */
    get(resourceGroupName: string, virtualNetworkGatewayName: string, natRuleName: string, callback: msRest.ServiceCallback<Models.VirtualNetworkGatewayNatRule>): void;
    /**
     * @param resourceGroupName The resource group name of the Virtual Network Gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, virtualNetworkGatewayName: string, natRuleName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.VirtualNetworkGatewayNatRule>): void;
    /**
     * Creates a nat rule to a scalable virtual network gateway if it doesn't exist else updates the
     * existing nat rules.
     * @param resourceGroupName The resource group name of the Virtual Network Gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param natRuleParameters Parameters supplied to create or Update a Nat Rule.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewayNatRulesCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, virtualNetworkGatewayName: string, natRuleName: string, natRuleParameters: Models.VirtualNetworkGatewayNatRule, options?: msRest.RequestOptionsBase): Promise<Models.VirtualNetworkGatewayNatRulesCreateOrUpdateResponse>;
    /**
     * Deletes a nat rule.
     * @param resourceGroupName The resource group name of the Virtual Network Gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, virtualNetworkGatewayName: string, natRuleName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Retrieves all nat rules for a particular virtual network gateway.
     * @param resourceGroupName The resource group name of the virtual network gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewayNatRulesListByVirtualNetworkGatewayResponse>
     */
    listByVirtualNetworkGateway(resourceGroupName: string, virtualNetworkGatewayName: string, options?: msRest.RequestOptionsBase): Promise<Models.VirtualNetworkGatewayNatRulesListByVirtualNetworkGatewayResponse>;
    /**
     * @param resourceGroupName The resource group name of the virtual network gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param callback The callback
     */
    listByVirtualNetworkGateway(resourceGroupName: string, virtualNetworkGatewayName: string, callback: msRest.ServiceCallback<Models.ListVirtualNetworkGatewayNatRulesResult>): void;
    /**
     * @param resourceGroupName The resource group name of the virtual network gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByVirtualNetworkGateway(resourceGroupName: string, virtualNetworkGatewayName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVirtualNetworkGatewayNatRulesResult>): void;
    /**
     * Creates a nat rule to a scalable virtual network gateway if it doesn't exist else updates the
     * existing nat rules.
     * @param resourceGroupName The resource group name of the Virtual Network Gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param natRuleParameters Parameters supplied to create or Update a Nat Rule.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, virtualNetworkGatewayName: string, natRuleName: string, natRuleParameters: Models.VirtualNetworkGatewayNatRule, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Deletes a nat rule.
     * @param resourceGroupName The resource group name of the Virtual Network Gateway.
     * @param virtualNetworkGatewayName The name of the gateway.
     * @param natRuleName The name of the nat rule.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, virtualNetworkGatewayName: string, natRuleName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Retrieves all nat rules for a particular virtual network gateway.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewayNatRulesListByVirtualNetworkGatewayNextResponse>
     */
    listByVirtualNetworkGatewayNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.VirtualNetworkGatewayNatRulesListByVirtualNetworkGatewayNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByVirtualNetworkGatewayNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ListVirtualNetworkGatewayNatRulesResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByVirtualNetworkGatewayNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVirtualNetworkGatewayNatRulesResult>): void;
}
//# sourceMappingURL=virtualNetworkGatewayNatRules.d.ts.map