/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/virtualNetworkGatewaysMappers";
import * as Parameters from "../models/parameters";
/** Class representing a VirtualNetworkGateways. */
var VirtualNetworkGateways = /** @class */ (function () {
    /**
     * Create a VirtualNetworkGateways.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function VirtualNetworkGateways(client) {
        this.client = client;
    }
    /**
     * Creates or updates a virtual network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param parameters Parameters supplied to create or update virtual network gateway operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysCreateOrUpdateResponse>
     */
    VirtualNetworkGateways.prototype.createOrUpdate = function (resourceGroupName, virtualNetworkGatewayName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, virtualNetworkGatewayName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualNetworkGateways.prototype.get = function (resourceGroupName, virtualNetworkGatewayName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Deletes the specified virtual network gateway.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VirtualNetworkGateways.prototype.deleteMethod = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.beginDeleteMethod(resourceGroupName, virtualNetworkGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Updates a virtual network gateway tags.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param parameters Parameters supplied to update virtual network gateway tags.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysUpdateTagsResponse>
     */
    VirtualNetworkGateways.prototype.updateTags = function (resourceGroupName, virtualNetworkGatewayName, parameters, options) {
        return this.beginUpdateTags(resourceGroupName, virtualNetworkGatewayName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualNetworkGateways.prototype.list = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listOperationSpec, callback);
    };
    VirtualNetworkGateways.prototype.listConnections = function (resourceGroupName, virtualNetworkGatewayName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            options: options
        }, listConnectionsOperationSpec, callback);
    };
    /**
     * Resets the primary of the virtual network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysResetResponse>
     */
    VirtualNetworkGateways.prototype.reset = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.beginReset(resourceGroupName, virtualNetworkGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Resets the VPN client shared key of the virtual network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VirtualNetworkGateways.prototype.resetVpnClientSharedKey = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.beginResetVpnClientSharedKey(resourceGroupName, virtualNetworkGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Generates VPN client package for P2S client of the virtual network gateway in the specified
     * resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param parameters Parameters supplied to the generate virtual network gateway VPN client package
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysGeneratevpnclientpackageResponse>
     */
    VirtualNetworkGateways.prototype.generatevpnclientpackage = function (resourceGroupName, virtualNetworkGatewayName, parameters, options) {
        return this.beginGeneratevpnclientpackage(resourceGroupName, virtualNetworkGatewayName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Generates VPN profile for P2S client of the virtual network gateway in the specified resource
     * group. Used for IKEV2 and radius based authentication.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param parameters Parameters supplied to the generate virtual network gateway VPN client package
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysGenerateVpnProfileResponse>
     */
    VirtualNetworkGateways.prototype.generateVpnProfile = function (resourceGroupName, virtualNetworkGatewayName, parameters, options) {
        return this.beginGenerateVpnProfile(resourceGroupName, virtualNetworkGatewayName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Gets pre-generated VPN profile for P2S client of the virtual network gateway in the specified
     * resource group. The profile needs to be generated first using generateVpnProfile.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysGetVpnProfilePackageUrlResponse>
     */
    VirtualNetworkGateways.prototype.getVpnProfilePackageUrl = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.beginGetVpnProfilePackageUrl(resourceGroupName, virtualNetworkGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * The GetBgpPeerStatus operation retrieves the status of all BGP peers.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysGetBgpPeerStatusResponse>
     */
    VirtualNetworkGateways.prototype.getBgpPeerStatus = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.beginGetBgpPeerStatus(resourceGroupName, virtualNetworkGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualNetworkGateways.prototype.supportedVpnDevices = function (resourceGroupName, virtualNetworkGatewayName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            options: options
        }, supportedVpnDevicesOperationSpec, callback);
    };
    /**
     * This operation retrieves a list of routes the virtual network gateway has learned, including
     * routes learned from BGP peers.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysGetLearnedRoutesResponse>
     */
    VirtualNetworkGateways.prototype.getLearnedRoutes = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.beginGetLearnedRoutes(resourceGroupName, virtualNetworkGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * This operation retrieves a list of routes the virtual network gateway is advertising to the
     * specified peer.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param peer The IP address of the peer.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysGetAdvertisedRoutesResponse>
     */
    VirtualNetworkGateways.prototype.getAdvertisedRoutes = function (resourceGroupName, virtualNetworkGatewayName, peer, options) {
        return this.beginGetAdvertisedRoutes(resourceGroupName, virtualNetworkGatewayName, peer, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * The Set VpnclientIpsecParameters operation sets the vpnclient ipsec policy for P2S client of
     * virtual network gateway in the specified resource group through Network resource provider.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param vpnclientIpsecParams Parameters supplied to the Begin Set vpnclient ipsec parameters of
     * Virtual Network Gateway P2S client operation through Network resource provider.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysSetVpnclientIpsecParametersResponse>
     */
    VirtualNetworkGateways.prototype.setVpnclientIpsecParameters = function (resourceGroupName, virtualNetworkGatewayName, vpnclientIpsecParams, options) {
        return this.beginSetVpnclientIpsecParameters(resourceGroupName, virtualNetworkGatewayName, vpnclientIpsecParams, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * The Get VpnclientIpsecParameters operation retrieves information about the vpnclient ipsec
     * policy for P2S client of virtual network gateway in the specified resource group through Network
     * resource provider.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The virtual network gateway name.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysGetVpnclientIpsecParametersResponse>
     */
    VirtualNetworkGateways.prototype.getVpnclientIpsecParameters = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.beginGetVpnclientIpsecParameters(resourceGroupName, virtualNetworkGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualNetworkGateways.prototype.vpnDeviceConfigurationScript = function (resourceGroupName, virtualNetworkGatewayConnectionName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayConnectionName: virtualNetworkGatewayConnectionName,
            parameters: parameters,
            options: options
        }, vpnDeviceConfigurationScriptOperationSpec, callback);
    };
    /**
     * Starts packet capture on virtual network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysStartPacketCaptureResponse>
     */
    VirtualNetworkGateways.prototype.startPacketCapture = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.beginStartPacketCapture(resourceGroupName, virtualNetworkGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Stops packet capture on virtual network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param parameters Virtual network gateway packet capture parameters supplied to stop packet
     * capture on gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysStopPacketCaptureResponse>
     */
    VirtualNetworkGateways.prototype.stopPacketCapture = function (resourceGroupName, virtualNetworkGatewayName, parameters, options) {
        return this.beginStopPacketCapture(resourceGroupName, virtualNetworkGatewayName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Get VPN client connection health detail per P2S client connection of the virtual network gateway
     * in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkGatewaysGetVpnclientConnectionHealthResponse>
     */
    VirtualNetworkGateways.prototype.getVpnclientConnectionHealth = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.beginGetVpnclientConnectionHealth(resourceGroupName, virtualNetworkGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Disconnect vpn connections of virtual network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param request The parameters are supplied to disconnect vpn connections.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VirtualNetworkGateways.prototype.disconnectVirtualNetworkGatewayVpnConnections = function (resourceGroupName, virtualNetworkGatewayName, request, options) {
        return this.beginDisconnectVirtualNetworkGatewayVpnConnections(resourceGroupName, virtualNetworkGatewayName, request, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Creates or updates a virtual network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param parameters Parameters supplied to create or update virtual network gateway operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginCreateOrUpdate = function (resourceGroupName, virtualNetworkGatewayName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes the specified virtual network gateway.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginDeleteMethod = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Updates a virtual network gateway tags.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param parameters Parameters supplied to update virtual network gateway tags.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginUpdateTags = function (resourceGroupName, virtualNetworkGatewayName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            parameters: parameters,
            options: options
        }, beginUpdateTagsOperationSpec, options);
    };
    /**
     * Resets the primary of the virtual network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginReset = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            options: options
        }, beginResetOperationSpec, options);
    };
    /**
     * Resets the VPN client shared key of the virtual network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginResetVpnClientSharedKey = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            options: options
        }, beginResetVpnClientSharedKeyOperationSpec, options);
    };
    /**
     * Generates VPN client package for P2S client of the virtual network gateway in the specified
     * resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param parameters Parameters supplied to the generate virtual network gateway VPN client package
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginGeneratevpnclientpackage = function (resourceGroupName, virtualNetworkGatewayName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            parameters: parameters,
            options: options
        }, beginGeneratevpnclientpackageOperationSpec, options);
    };
    /**
     * Generates VPN profile for P2S client of the virtual network gateway in the specified resource
     * group. Used for IKEV2 and radius based authentication.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param parameters Parameters supplied to the generate virtual network gateway VPN client package
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginGenerateVpnProfile = function (resourceGroupName, virtualNetworkGatewayName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            parameters: parameters,
            options: options
        }, beginGenerateVpnProfileOperationSpec, options);
    };
    /**
     * Gets pre-generated VPN profile for P2S client of the virtual network gateway in the specified
     * resource group. The profile needs to be generated first using generateVpnProfile.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginGetVpnProfilePackageUrl = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            options: options
        }, beginGetVpnProfilePackageUrlOperationSpec, options);
    };
    /**
     * The GetBgpPeerStatus operation retrieves the status of all BGP peers.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginGetBgpPeerStatus = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            options: options
        }, beginGetBgpPeerStatusOperationSpec, options);
    };
    /**
     * This operation retrieves a list of routes the virtual network gateway has learned, including
     * routes learned from BGP peers.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginGetLearnedRoutes = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            options: options
        }, beginGetLearnedRoutesOperationSpec, options);
    };
    /**
     * This operation retrieves a list of routes the virtual network gateway is advertising to the
     * specified peer.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param peer The IP address of the peer.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginGetAdvertisedRoutes = function (resourceGroupName, virtualNetworkGatewayName, peer, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            peer: peer,
            options: options
        }, beginGetAdvertisedRoutesOperationSpec, options);
    };
    /**
     * The Set VpnclientIpsecParameters operation sets the vpnclient ipsec policy for P2S client of
     * virtual network gateway in the specified resource group through Network resource provider.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param vpnclientIpsecParams Parameters supplied to the Begin Set vpnclient ipsec parameters of
     * Virtual Network Gateway P2S client operation through Network resource provider.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginSetVpnclientIpsecParameters = function (resourceGroupName, virtualNetworkGatewayName, vpnclientIpsecParams, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            vpnclientIpsecParams: vpnclientIpsecParams,
            options: options
        }, beginSetVpnclientIpsecParametersOperationSpec, options);
    };
    /**
     * The Get VpnclientIpsecParameters operation retrieves information about the vpnclient ipsec
     * policy for P2S client of virtual network gateway in the specified resource group through Network
     * resource provider.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The virtual network gateway name.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginGetVpnclientIpsecParameters = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            options: options
        }, beginGetVpnclientIpsecParametersOperationSpec, options);
    };
    /**
     * Starts packet capture on virtual network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginStartPacketCapture = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            options: options
        }, beginStartPacketCaptureOperationSpec, options);
    };
    /**
     * Stops packet capture on virtual network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param parameters Virtual network gateway packet capture parameters supplied to stop packet
     * capture on gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginStopPacketCapture = function (resourceGroupName, virtualNetworkGatewayName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            parameters: parameters,
            options: options
        }, beginStopPacketCaptureOperationSpec, options);
    };
    /**
     * Get VPN client connection health detail per P2S client connection of the virtual network gateway
     * in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginGetVpnclientConnectionHealth = function (resourceGroupName, virtualNetworkGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            options: options
        }, beginGetVpnclientConnectionHealthOperationSpec, options);
    };
    /**
     * Disconnect vpn connections of virtual network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkGatewayName The name of the virtual network gateway.
     * @param request The parameters are supplied to disconnect vpn connections.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkGateways.prototype.beginDisconnectVirtualNetworkGatewayVpnConnections = function (resourceGroupName, virtualNetworkGatewayName, request, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkGatewayName: virtualNetworkGatewayName,
            request: request,
            options: options
        }, beginDisconnectVirtualNetworkGatewayVpnConnectionsOperationSpec, options);
    };
    VirtualNetworkGateways.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    VirtualNetworkGateways.prototype.listConnectionsNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listConnectionsNextOperationSpec, callback);
    };
    return VirtualNetworkGateways;
}());
export { VirtualNetworkGateways };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGateway
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGatewayListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listConnectionsOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/connections",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGatewayListConnectionsResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var supportedVpnDevicesOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/supportedvpndevices",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "String"
                }
            }
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var vpnDeviceConfigurationScriptOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/connections/{virtualNetworkGatewayConnectionName}/vpndeviceconfigurationscript",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.VpnDeviceScriptParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "String"
                }
            }
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.VirtualNetworkGateway), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGateway
        },
        201: {
            bodyMapper: Mappers.VirtualNetworkGateway
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginUpdateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGateway
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginResetOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/reset",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.gatewayVip,
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGateway
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginResetVpnClientSharedKeyOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/resetvpnclientsharedkey",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginGeneratevpnclientpackageOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/generatevpnclientpackage",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.VpnClientParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "String"
                }
            }
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginGenerateVpnProfileOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/generatevpnprofile",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.VpnClientParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "String"
                }
            }
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginGetVpnProfilePackageUrlOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/getvpnprofilepackageurl",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "String"
                }
            }
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginGetBgpPeerStatusOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/getBgpPeerStatus",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.peer0,
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.BgpPeerStatusListResult
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginGetLearnedRoutesOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/getLearnedRoutes",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.GatewayRouteListResult
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginGetAdvertisedRoutesOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/getAdvertisedRoutes",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.peer1,
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.GatewayRouteListResult
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginSetVpnclientIpsecParametersOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/setvpnclientipsecparameters",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "vpnclientIpsecParams",
        mapper: __assign(__assign({}, Mappers.VpnClientIPsecParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VpnClientIPsecParameters
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginGetVpnclientIpsecParametersOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/getvpnclientipsecparameters",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VpnClientIPsecParameters
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginStartPacketCaptureOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/startPacketCapture",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: [
            "options",
            "parameters"
        ],
        mapper: Mappers.VpnPacketCaptureStartParameters
    },
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "String"
                }
            }
        },
        202: {},
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var beginStopPacketCaptureOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/stopPacketCapture",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.VpnPacketCaptureStopParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "String"
                }
            }
        },
        202: {},
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var beginGetVpnclientConnectionHealthOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/getVpnClientConnectionHealth",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VpnClientConnectionHealthDetailListResult
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDisconnectVirtualNetworkGatewayVpnConnectionsOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworkGateways/{virtualNetworkGatewayName}/disconnectVirtualNetworkGatewayVpnConnections",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualNetworkGatewayName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "request",
        mapper: __assign(__assign({}, Mappers.P2SVpnConnectionRequest), { required: true })
    },
    responses: {
        200: {},
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGatewayListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listConnectionsNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkGatewayListConnectionsResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=virtualNetworkGateways.js.map