/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/vpnSitesConfigurationMappers";
import * as Parameters from "../models/parameters";
/** Class representing a VpnSitesConfiguration. */
var VpnSitesConfiguration = /** @class */ (function () {
    /**
     * Create a VpnSitesConfiguration.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function VpnSitesConfiguration(client) {
        this.client = client;
    }
    /**
     * Gives the sas-url to download the configurations for vpn-sites in a resource group.
     * @param resourceGroupName The resource group name.
     * @param virtualWANName The name of the VirtualWAN for which configuration of all vpn-sites is
     * needed.
     * @param request Parameters supplied to download vpn-sites configuration.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VpnSitesConfiguration.prototype.download = function (resourceGroupName, virtualWANName, request, options) {
        return this.beginDownload(resourceGroupName, virtualWANName, request, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Gives the sas-url to download the configurations for vpn-sites in a resource group.
     * @param resourceGroupName The resource group name.
     * @param virtualWANName The name of the VirtualWAN for which configuration of all vpn-sites is
     * needed.
     * @param request Parameters supplied to download vpn-sites configuration.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VpnSitesConfiguration.prototype.beginDownload = function (resourceGroupName, virtualWANName, request, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualWANName: virtualWANName,
            request: request,
            options: options
        }, beginDownloadOperationSpec, options);
    };
    return VpnSitesConfiguration;
}());
export { VpnSitesConfiguration };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var beginDownloadOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualWans/{virtualWANName}/vpnConfiguration",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualWANName0
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "request",
        mapper: __assign(__assign({}, Mappers.GetVpnSitesConfigurationRequest), { required: true })
    },
    responses: {
        200: {},
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=vpnSitesConfiguration.js.map