import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { PrivateDnsManagementClientContext } from "../privateDnsManagementClientContext";
/** Class representing a VirtualNetworkLinks. */
export declare class VirtualNetworkLinks {
    private readonly client;
    /**
     * Create a VirtualNetworkLinks.
     * @param {PrivateDnsManagementClientContext} client Reference to the service client.
     */
    constructor(client: PrivateDnsManagementClientContext);
    /**
     * Creates or updates a virtual network link to the specified Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param parameters Parameters supplied to the CreateOrUpdate operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkLinksCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, privateZoneName: string, virtualNetworkLinkName: string, parameters: Models.VirtualNetworkLink, options?: Models.VirtualNetworkLinksCreateOrUpdateOptionalParams): Promise<Models.VirtualNetworkLinksCreateOrUpdateResponse>;
    /**
     * Updates a virtual network link to the specified Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param parameters Parameters supplied to the Update operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkLinksUpdateResponse>
     */
    update(resourceGroupName: string, privateZoneName: string, virtualNetworkLinkName: string, parameters: Models.VirtualNetworkLink, options?: Models.VirtualNetworkLinksUpdateOptionalParams): Promise<Models.VirtualNetworkLinksUpdateResponse>;
    /**
     * Deletes a virtual network link to the specified Private DNS zone. WARNING: In case of a
     * registration virtual network, all auto-registered DNS records in the zone for the virtual
     * network will also be deleted. This operation cannot be undone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, privateZoneName: string, virtualNetworkLinkName: string, options?: Models.VirtualNetworkLinksDeleteMethodOptionalParams): Promise<msRest.RestResponse>;
    /**
     * Gets a virtual network link to the specified Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkLinksGetResponse>
     */
    get(resourceGroupName: string, privateZoneName: string, virtualNetworkLinkName: string, options?: msRest.RequestOptionsBase): Promise<Models.VirtualNetworkLinksGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param callback The callback
     */
    get(resourceGroupName: string, privateZoneName: string, virtualNetworkLinkName: string, callback: msRest.ServiceCallback<Models.VirtualNetworkLink>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, privateZoneName: string, virtualNetworkLinkName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.VirtualNetworkLink>): void;
    /**
     * Lists the virtual network links to the specified Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkLinksListResponse>
     */
    list(resourceGroupName: string, privateZoneName: string, options?: Models.VirtualNetworkLinksListOptionalParams): Promise<Models.VirtualNetworkLinksListResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param callback The callback
     */
    list(resourceGroupName: string, privateZoneName: string, callback: msRest.ServiceCallback<Models.VirtualNetworkLinkListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, privateZoneName: string, options: Models.VirtualNetworkLinksListOptionalParams, callback: msRest.ServiceCallback<Models.VirtualNetworkLinkListResult>): void;
    /**
     * Creates or updates a virtual network link to the specified Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param parameters Parameters supplied to the CreateOrUpdate operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, privateZoneName: string, virtualNetworkLinkName: string, parameters: Models.VirtualNetworkLink, options?: Models.VirtualNetworkLinksBeginCreateOrUpdateOptionalParams): Promise<msRestAzure.LROPoller>;
    /**
     * Updates a virtual network link to the specified Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param parameters Parameters supplied to the Update operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginUpdate(resourceGroupName: string, privateZoneName: string, virtualNetworkLinkName: string, parameters: Models.VirtualNetworkLink, options?: Models.VirtualNetworkLinksBeginUpdateOptionalParams): Promise<msRestAzure.LROPoller>;
    /**
     * Deletes a virtual network link to the specified Private DNS zone. WARNING: In case of a
     * registration virtual network, all auto-registered DNS records in the zone for the virtual
     * network will also be deleted. This operation cannot be undone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, privateZoneName: string, virtualNetworkLinkName: string, options?: Models.VirtualNetworkLinksBeginDeleteMethodOptionalParams): Promise<msRestAzure.LROPoller>;
    /**
     * Lists the virtual network links to the specified Private DNS zone.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkLinksListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.VirtualNetworkLinksListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.VirtualNetworkLinkListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.VirtualNetworkLinkListResult>): void;
}
//# sourceMappingURL=virtualNetworkLinks.d.ts.map