/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/virtualNetworkLinksMappers";
import * as Parameters from "../models/parameters";
/** Class representing a VirtualNetworkLinks. */
var VirtualNetworkLinks = /** @class */ (function () {
    /**
     * Create a VirtualNetworkLinks.
     * @param {PrivateDnsManagementClientContext} client Reference to the service client.
     */
    function VirtualNetworkLinks(client) {
        this.client = client;
    }
    /**
     * Creates or updates a virtual network link to the specified Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param parameters Parameters supplied to the CreateOrUpdate operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkLinksCreateOrUpdateResponse>
     */
    VirtualNetworkLinks.prototype.createOrUpdate = function (resourceGroupName, privateZoneName, virtualNetworkLinkName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, privateZoneName, virtualNetworkLinkName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Updates a virtual network link to the specified Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param parameters Parameters supplied to the Update operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkLinksUpdateResponse>
     */
    VirtualNetworkLinks.prototype.update = function (resourceGroupName, privateZoneName, virtualNetworkLinkName, parameters, options) {
        return this.beginUpdate(resourceGroupName, privateZoneName, virtualNetworkLinkName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes a virtual network link to the specified Private DNS zone. WARNING: In case of a
     * registration virtual network, all auto-registered DNS records in the zone for the virtual
     * network will also be deleted. This operation cannot be undone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VirtualNetworkLinks.prototype.deleteMethod = function (resourceGroupName, privateZoneName, virtualNetworkLinkName, options) {
        return this.beginDeleteMethod(resourceGroupName, privateZoneName, virtualNetworkLinkName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualNetworkLinks.prototype.get = function (resourceGroupName, privateZoneName, virtualNetworkLinkName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            virtualNetworkLinkName: virtualNetworkLinkName,
            options: options
        }, getOperationSpec, callback);
    };
    VirtualNetworkLinks.prototype.list = function (resourceGroupName, privateZoneName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Creates or updates a virtual network link to the specified Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param parameters Parameters supplied to the CreateOrUpdate operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkLinks.prototype.beginCreateOrUpdate = function (resourceGroupName, privateZoneName, virtualNetworkLinkName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            virtualNetworkLinkName: virtualNetworkLinkName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Updates a virtual network link to the specified Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param parameters Parameters supplied to the Update operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkLinks.prototype.beginUpdate = function (resourceGroupName, privateZoneName, virtualNetworkLinkName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            virtualNetworkLinkName: virtualNetworkLinkName,
            parameters: parameters,
            options: options
        }, beginUpdateOperationSpec, options);
    };
    /**
     * Deletes a virtual network link to the specified Private DNS zone. WARNING: In case of a
     * registration virtual network, all auto-registered DNS records in the zone for the virtual
     * network will also be deleted. This operation cannot be undone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param virtualNetworkLinkName The name of the virtual network link.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkLinks.prototype.beginDeleteMethod = function (resourceGroupName, privateZoneName, virtualNetworkLinkName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            virtualNetworkLinkName: virtualNetworkLinkName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    VirtualNetworkLinks.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return VirtualNetworkLinks;
}());
export { VirtualNetworkLinks };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}/virtualNetworkLinks/{virtualNetworkLinkName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.virtualNetworkLinkName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkLink
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}/virtualNetworkLinks",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.top,
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkLinkListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}/virtualNetworkLinks/{virtualNetworkLinkName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.virtualNetworkLinkName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.ifMatch,
        Parameters.ifNoneMatch,
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.VirtualNetworkLink), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkLink
        },
        201: {
            bodyMapper: Mappers.VirtualNetworkLink
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginUpdateOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}/virtualNetworkLinks/{virtualNetworkLinkName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.virtualNetworkLinkName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.ifMatch,
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.VirtualNetworkLink), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkLink
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}/virtualNetworkLinks/{virtualNetworkLinkName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.virtualNetworkLinkName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.ifMatch,
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkLinkListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=virtualNetworkLinks.js.map